@@ -8,12 +8,12 @@ from collections import OrderedDict, defaultdict
 from conan.api.output import ConanOutput
 from conan.errors import ConanException
 from conan.internal.model.pkg_type import PackageType
-from conans.util.files import load, save
+from conan.internal.util.files import load, save
 
 _DIRS_VAR_NAMES = ["_includedirs", "_srcdirs", "_libdirs", "_resdirs", "_bindirs", "_builddirs",
                    "_frameworkdirs", "_objects"]
-_FIELD_VAR_NAMES = ["_system_libs", "_frameworks", "_libs", "_defines", "_cflags", "_cxxflags",
-                    "_sharedlinkflags", "_exelinkflags"]
+_FIELD_VAR_NAMES = ["_system_libs", "_package_framework", "_frameworks", "_libs", "_defines",
+                    "_cflags", "_cxxflags", "_sharedlinkflags", "_exelinkflags"]
 _ALL_NAMES = _DIRS_VAR_NAMES + _FIELD_VAR_NAMES
 
 
@@ -72,7 +72,8 @@ class _Component:
 
         # ##### FIELDS
         self._system_libs = None  # Ordered list of system libraries
-        self._frameworks = None  # Macos .framework
+        self._frameworks = None  # system Apple OS frameworks
+        self._package_framework = None  # any other frameworks
         self._libs = None  # The libs to link against
         self._defines = None  # preprocessor definitions
         self._cflags = None  # pure C flags
@@ -204,16 +205,6 @@ class _Component:
     def builddirs(self, value):
         self._builddirs = value
 
-    @property
-    def frameworkdirs(self):
-        if self._frameworkdirs is None:
-            self._frameworkdirs = []
-        return self._frameworkdirs
-
-    @frameworkdirs.setter
-    def frameworkdirs(self, value):
-        self._frameworkdirs = value
-
     @property
     def bindir(self):
         bindirs = self.bindirs
@@ -251,6 +242,14 @@ class _Component:
     def system_libs(self, value):
         self._system_libs = value
 
+    @property
+    def package_framework(self):
+        return self._package_framework
+
+    @package_framework.setter
+    def package_framework(self, value):
+        self._package_framework = value
+
     @property
     def frameworks(self):
         if self._frameworks is None:
@@ -261,6 +260,16 @@ class _Component:
     def frameworks(self, value):
         self._frameworks = value
 
+    @property
+    def frameworkdirs(self):
+        if self._frameworkdirs is None:
+            self._frameworkdirs = []
+        return self._frameworkdirs
+
+    @frameworkdirs.setter
+    def frameworkdirs(self, value):
+        self._frameworkdirs = value
+
     @property
     def libs(self):
         if self._libs is None:
@@ -502,16 +511,8 @@ class _Component:
             for file_name in files:
                 full_path = os.path.join(dir_, file_name)
                 if os.path.isfile(full_path) and pattern.match(file_name):
-                    # File name could be a symlink, e.g., mylib.1.0.0.so -> mylib.so
-                    if os.path.islink(full_path):
-                        # Important! os.path.realpath returns the final path of the symlink even if it points
-                        # to another symlink, i.e., libmylib.dylib -> libmylib.1.dylib -> libmylib.1.0.0.dylib
-                        # then os.path.realpath("libmylib.1.0.0.dylib") == "libmylib.dylib"
-                        # Note: os.readlink() returns the path which the symbolic link points to.
-                        real_path = os.path.realpath(full_path)
-                        ret.add(real_path)
-                    else:
-                        ret.add(full_path)
+                    # Issue: https://github.com/conan-io/conan/issues/17721 (stop resolving symlinks)
+                    ret.add(full_path)
             return list(ret)
 
         def _find_matching(dirs, pattern):
@@ -527,7 +528,9 @@ class _Component:
                 if lib_found:
                     if len(lib_found) > 1:
                         lib_found.sort()
-                        out.warning(f"There were several matches for Lib {libname}: {lib_found}")
+                        found, _ = os.path.splitext(os.path.basename(lib_found[0]))
+                        if found != libname and found != f"lib{libname}":
+                            out.warning(f"There were several matches for Lib {libname}: {lib_found}")
                     return lib_found[0].replace("\\", "/")
 
         out = ConanOutput(scope=str(conanfile))
@@ -551,11 +554,18 @@ class _Component:
         else:
             lib_sanitized = re.escape(libname)
             component_sanitized = re.escape(library_name)
-            regex_static = re.compile(rf"(?:lib)?{lib_sanitized}(?:[._-].+)?\.(?:a|lib)")
-            regex_shared = re.compile(rf"(?:lib)?{lib_sanitized}(?:[._-].+)?\.(?:so|dylib)")
+            # At first, exact match
+            regex_static = re.compile(rf"(?:lib)?{lib_sanitized}\.(?:a|lib)")
+            regex_shared = re.compile(rf"(?:lib)?{lib_sanitized}\.(?:so|dylib)")
             regex_dll = re.compile(rf".*(?:{lib_sanitized}|{component_sanitized}).*\.dll")
             static_location = _find_matching(libdirs, regex_static)
             shared_location = _find_matching(libdirs, regex_shared)
+            if not any([static_location, shared_location]):
+                # Let's extend a little bit the pattern search
+                regex_wider_static = re.compile(rf"(?:lib)?{lib_sanitized}(?:[._-].+)?\.(?:a|lib)")
+                regex_wider_shared = re.compile(rf"(?:lib)?{lib_sanitized}(?:[._-].+)?\.(?:so|dylib)")
+                static_location = _find_matching(libdirs, regex_wider_static)
+                shared_location = _find_matching(libdirs, regex_wider_shared)
             if static_location or not shared_location:
                 dll_location = _find_matching(bindirs, regex_dll)
 
@@ -610,7 +620,7 @@ class _Component:
                 raise ConanException(f"{name} has .exe and no .location")
             return
         if self._type is PackageType.APP:
-            # old school Conan application packages withoud defining an exe, not an error
+            # old school Conan application packages without defining an exe, not an error
             return
 
         # libraries
@@ -649,7 +659,7 @@ class CppInfo:
         return getattr(self._package, attr)
 
     def __setattr__(self, attr, value):
-        if attr in ("components", "default_components", "_package", "_aggregated"):
+        if attr in ("components", "default_components", "_package", "_aggregated", "required_components"):
             super(CppInfo, self).__setattr__(attr, value)
         else:
             setattr(self._package, attr, value)
@@ -770,7 +780,9 @@ class CppInfo:
         comps = self.required_components
         missing_internal = [c[1] for c in comps if c[0] is None and c[1] not in self.components]
         if missing_internal:
-            raise ConanException(f"{conanfile}: Internal components not found: {missing_internal}")
+            msg = f"{conanfile}: package_info(): There are '(cpp_info/components).requires' to " \
+                  f"other internal components that are not defined: {missing_internal}"
+            raise ConanException(msg)
         external = [c[0] for c in comps if c[0] is not None]
         if not external:
             return
@@ -782,13 +794,16 @@ class CppInfo:
 
         for e in external:
             if e not in direct_dependencies:
-                raise ConanException(
-                    f"{conanfile}: required component package '{e}::' not in dependencies")
+                msg = f"{conanfile}: package_info(): There are '(cpp_info/components).requires' " \
+                      f"that includes package '{e}::', but such package is not a a direct " \
+                      f"requirement of the recipe"
+                raise ConanException(msg)
         # TODO: discuss if there are cases that something is required but not transitive
         for e in direct_dependencies:
             if e not in external:
-                raise ConanException(
-                    f"{conanfile}: Required package '{e}' not in component 'requires'")
+                msg = f"{conanfile}: package_info(): The direct dependency '{e}' is not used by " \
+                      f"any '(cpp_info/components).requires'."
+                raise ConanException(msg)
 
     @property
     def required_components(self):
@@ -810,10 +825,10 @@ class CppInfo:
             raise ConanException(f"{conanfile}: 'cpp_info' contains components and .exe or .libs")
 
         result = CppInfo()  # clone it
-
         if self.libs and len(self.libs) > 1:  # expand in multiple components
-            ConanOutput().warning(f"{conanfile}: The 'cpp_info.libs' contain more than 1 library. "
-                                  "Define 'cpp_info.components' instead.")
+            ConanOutput(scope=str(conanfile)).warning(
+                "The 'cpp_info.libs' contain more than 1 library. "
+                "Define 'cpp_info.components' instead.", warn_tag="deprecated")
             assert not self.components, f"{conanfile} cpp_info shouldn't have .libs and .components"
             common = self._package.clone()
             common.libs = []
@@ -832,7 +847,30 @@ class CppInfo:
         else:
             result._package = self._package.clone()
             result.default_components = self.default_components
-            result.components = {k: v.clone() for k, v in self.components.items()}
+            new_components = {}
+            for k, v in self.components.items():
+                if v.libs and len(v.libs) > 1:
+                    ConanOutput(scope=str(conanfile)).warning(
+                        f"The 'cpp_info.components[{k}] contains more than 1 library. "
+                        "Define 1 component for each library instead.", warn_tag="deprecated")
+                    # Now the root, empty one
+                    common = v.clone()
+                    common.libs = []
+                    common.type = str(PackageType.HEADER)  # the type of components is a string!
+                    new_components[k] = common
+
+                    for lib in v.libs:
+                        c = _Component()
+                        c.type = v.type
+                        c.includedirs = v.includedirs
+                        c.libdirs = v.libdirs
+                        c.bindirs = v.bindirs
+                        c.libs = [lib]
+                        new_components[f"_{k}_{lib}"] = c
+                        common.requires.append(f"_{k}_{lib}")
+                else:
+                    new_components[k] = v.clone()
+            result.components = new_components
 
         result._package.deduce_locations(conanfile)
         for comp_name, comp in result.components.items():
